// $Id: ConfigurationDialog.cpp,v 1.27 2012/01/01 22:48:52 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Application.h"
#include "ConfigurationDialog.h"
#include "Debug.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "BaseIcons.h"
#include "MainWindow.h"
#include "OptionComboBox.h"
#include "OptionColorDisplay.h"
#include "OptionSpinBox.h"
#include "Options.h"
#include "QtUtil.h"
#include "ServerConfiguration.h"
#include "Singleton.h"
#include "TreeView.h"
#include "TreeViewConfiguration.h"

#include <QtGui/QLabel>
#include <QtGui/QToolTip>
#include <QtGui/QGroupBox>
#include <QtGui/QLayout>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
BaseConfigurationDialog( parent )
{


    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setWindowTitle( "Configuration - Serverlog" );

    // base configuration
    baseConfiguration( 0 );


    // generic objects
    QGroupBox *box;

    // appearance
    QWidget* page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE ), "Appearance", "Main window appearance and colors" );

    page->layout()->addWidget( box = new QGroupBox( "Colors",  page ) );
    GridLayout* gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    box->setLayout( gridLayout );

    // colors
    gridLayout->addWidget( new QLabel( "Server application: ", box ) );
    OptionColorDisplay* color = new OptionColorDisplay( box, "SERVER_COLOR" );
    color->setToolTip( "Item color for server application" );
    gridLayout->addWidget( color );
    addOptionWidget( color );

    gridLayout->addWidget( new QLabel( "Identify requests: ", box ) );
    color = new OptionColorDisplay( box, "IDENTIFY_COLOR" );
    color->setToolTip( "Item color for identification requests" );
    gridLayout->addWidget( color );
    addOptionWidget( color );

    page->layout()->addWidget( box = new QGroupBox( "Misc",  page ) );
    box->setLayout( new QVBoxLayout() );
    box->layout()->setMargin(5);
    box->layout()->setSpacing(5);

    gridLayout = new GridLayout();
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    gridLayout->setMaxCount(2);
    box->layout()->addItem( gridLayout );

    // verbosity
    gridLayout->addWidget( new QLabel( "Verbosity: ", box ) );
    OptionComboBox* combobox = new OptionComboBox( box, "VERBOSITY" );
    combobox->addItem( MainWindow::VERBOSITY_LOW );
    combobox->addItem( MainWindow::VERBOSITY_HIGH );
    gridLayout->addWidget( combobox );
    addOptionWidget( combobox );
    combobox->setToolTip( "List display verbosity" );

    SERVER::ServerConfiguration* server_configuration;

    // server
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_SERVER ), "Server", "Client/server connection to other server-oriented applications" );
    page->layout()->addWidget( server_configuration = new SERVER::ServerConfiguration( page ));
    addOptionWidget( server_configuration );

    // load initial configuration
    _read();

}
