// $Id: Menu.cpp,v 1.17 2011/11/22 19:25:19 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.	See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

/*!
\file Menu.cc
\brief main menu
\author Hugo Pereira
\version $Revision: 1.17 $
\date $Date: 2011/11/22 19:25:19 $
*/



#include "Application.h"
#include "CustomToolBar.h"
#include "DebugMenu.h"
#include "Menu.h"
#include "MainWindow.h"
#include "Singleton.h"
#include "XmlOptions.h"




//_______________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{
    Debug::Throw( "Menu::Menu.\n" );

    // application
    Application& application( *Singleton::get().application<Application>() );

    // top widget
    MainWindow& mainwindow( *static_cast<MainWindow*>( window() ) );

    // generic menu
    QMenu* menu;

    // file menu
    menu = addMenu( "File" );
    menu->addAction( &application.closeAction() );

    // create edit menu
    menu = addMenu( "Tools" );
    menu->addAction( &mainwindow.resetAction() );
    menu->addAction( &mainwindow.unlockAction() );
    menu->addSeparator();
    menu->addAction( &mainwindow.raiseAction() );
    menu->addAction( &mainwindow.abortAction() );

    // Settings menu
    menu = addMenu( "Settings" );

    // verbosity menu
    verbosityMenu_ = menu->addMenu( "&Verbosity" );
    QActionGroup* verbosity_group = new QActionGroup( menu );
    verbosity_group->setExclusive( true );
    verbosityLow_ = verbosity_group->addAction( "&low" );
    verbosityHigh_ = verbosity_group->addAction( "&high" );
    verbosityLow_->setCheckable( true );
    verbosityHigh_->setCheckable( true );
    verbosityMenu_->addActions( verbosity_group->actions() );

    connect( verbosityMenu_, SIGNAL( aboutToShow() ), SLOT( _updateVerbosityMenu() ) );
    connect( verbosityMenu_, SIGNAL( triggered( QAction* ) ), SLOT( _toggleVerbosity( QAction* ) ) );

    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // help menu
    menu = addMenu( "Help" );
    menu->addAction( &application.aboutQtAction() );
    menu->addAction( &application.aboutAction() );

    // debug menu
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debug_menu( new DebugMenu( this ) );
    debug_menu->setTitle( "Debug" );
    menu->addMenu( debug_menu );
    #endif

}

//_______________________________________________
void Menu::_updateVerbosityMenu( void )
{
    Debug::Throw( "Menu::_UpdateVerbosityMenu.\n" );

    QString verbosity( XmlOptions::get().raw("VERBOSITY") );
    verbosityLow_->setChecked( verbosity == MainWindow::VERBOSITY_LOW );
    verbosityHigh_->setChecked( verbosity == MainWindow::VERBOSITY_HIGH );

}

//_______________________________________________
void Menu::_toggleVerbosity( QAction* action )
{
    Debug::Throw( "Menu::_toggleVerbosity.\n" );

    XmlOptions::get().set( "VERBOSITY", (verbosityLow_->isChecked()) ? MainWindow::VERBOSITY_LOW:MainWindow::VERBOSITY_HIGH );
    XmlOptions::write();

    static_cast<MainWindow*>(window())->setVerbosity( XmlOptions::get().raw( "VERBOSITY" ) );

}
