#ifndef ServerCommandModel_h
#define ServerCommandModel_h

// $Id: ServerCommandModel.h,v 1.11 2011/11/22 14:51:50 hpereira Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *
 *******************************************************************************/

/*!
  \file    ServerCommandModel.h
  \brief   server commands model
  \author  Hugo Pereira
  \version $Revision: 1.11 $
  \date    $Date: 2011/11/22 14:51:50 $
*/

#include "Counter.h"
#include "ServerCommand.h"
#include "TreeModel.h"

#include <QtGui/QColor>
#include <QtGui/QIcon>

//! ServerCommand model. Stores job information for display in lists
class ServerCommandModel : public TreeModel<SERVER::ServerCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! column type enumeration
    enum ColumnTypes
    {
        NAME,
        USER,
        DISPLAY,
        COMMAND,
        STAMP
    };

    //! constructor
    ServerCommandModel(QObject *parent = 0);

    //! destructor
    virtual ~ServerCommandModel()
    {}

    //!@name methods reimplemented from base class
    //@{

    //! return data
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    { return nColumns; }

    //@}

    //! server color
    const QColor& serverColor( void ) const
    { return serverColor_; }

    //! server color
    bool setServerColor( const QColor& color )
    {
        if( serverColor_ == color ) return false;
        serverColor_ = color;
        return true;
    }

    //! identify request colors
    const QColor& identifyColor( void ) const
    { return identifyColor_; }

    //! identify request color
    bool setIdentifyColor( const QColor& color )
    {
        if( identifyColor_ == color ) return false;
        identifyColor_ = color;
        return true;
    }

    protected:

    //! sorting
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    { _root().sort( SortFTor( (ColumnTypes) column, order ) ); }

    private:

    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
        {}

        //! prediction
        bool operator() ( const Item& first, const Item& second ) const
        { return (*this)( first.get(), second.get() ); }

        //! prediction
        bool operator() ( SERVER::ServerCommand, SERVER::ServerCommand ) const;

    };

    //! number of columns
    enum { nColumns = 5 };

    //! column titles
    static const QString columnTitles_[ nColumns ];

    //! colors
    QColor identifyColor_;

    //! colors
    QColor serverColor_;

};

#endif
